/*
 *  Copyright 2019-2025 Zheng Jie
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.fuyuanshen.modules.system.domain.app;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fuyuanshen.base.BaseEntity;
import com.fuyuanshen.modules.system.domain.Dept;
import com.fuyuanshen.modules.system.domain.Job;
import com.fuyuanshen.modules.system.domain.Role;
import com.fuyuanshen.modules.system.domain.User;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Date;
import java.util.Set;

/**
 * @author Zheng Jie
 * @date 2018-11-22
 */
@Data
@TableName("app_user")
public class APPUser extends BaseEntity implements Serializable {

    @NotNull(groups = Update.class)
    @TableId(value = "app_user_id", type = IdType.AUTO)
    @ApiModelProperty(value = "ID", hidden = true)
    private Long id;

    @TableField(value = "dept_id")
    @ApiModelProperty(hidden = true)
    private Long deptId;

    @TableField(exist = false)
    @ApiModelProperty(value = "用户角色")
    private Set<Role> roles;

    @ApiModelProperty(hidden = true)
    private Long pid;

    @TableField(value = "user_level")
    @ApiModelProperty(hidden = true)
    private Byte userLevel;

    @ApiModelProperty(value = "用户部门")
    @TableField(exist = false)
    private Dept dept;

    @NotBlank
    @ApiModelProperty(value = "账号")
    private String username;

    // @NotBlank
    @ApiModelProperty(value = "用户昵称")
    private String nickName;

    @Email
    // @NotBlank
    @ApiModelProperty(value = "邮箱")
    private String email;

    // @NotBlank
    @ApiModelProperty(value = "电话号码")
    private Long phone;

    @ApiModelProperty(value = "用户性别")
    private String gender;

    @ApiModelProperty(value = "头像真实名称", hidden = true)
    private String avatarName;

    @ApiModelProperty(value = "头像存储的路径", hidden = true)
    private String avatarPath;

    @ApiModelProperty(value = "密码")
    private String password;

    @NotNull
    @ApiModelProperty(value = "是否启用")
    private Boolean enabled;

    /**
     * 是否为admin账号
     * 0否
     * 1是
     */
    @ApiModelProperty(value = "是否为admin账号", hidden = true)
    @TableField(value = "is_admin")
    private Byte admin = 0;

    @TableField(exist = false)
    private Boolean isAdmin = false;

    @ApiModelProperty(value = "最后修改密码的时间", hidden = true)
    private Date pwdResetTime;

    /**
     * 租户ID
     */
    @TableField(value = "tenant_id")
    @ApiModelProperty(hidden = true)
    private Long tenantId;


    /**
     * 用户类型
     * 0 app
     * 1 小程序
     */
    @TableField(value = "user_type")
    @ApiModelProperty(hidden = true)
    private Integer userType;

    /**
     * 地区
     */
    private String region;
}