/*
 *  Copyright 2019-2025 Zheng Jie
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.fuyuanshen.modules.system.mapper.app;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fuyuanshen.modules.security.service.dto.app.AppRoleDto;
import com.fuyuanshen.modules.system.domain.User;
import com.fuyuanshen.modules.system.domain.app.APPUser;
import com.fuyuanshen.modules.system.domain.dto.UserQueryCriteria;
import com.fuyuanshen.modules.system.domain.query.APPUserQuery;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import javax.validation.constraints.NotBlank;

/**
 * @author Zheng Jie
 * @date 2023-06-20
 */
@Mapper
public interface APPUserMapper extends BaseMapper<APPUser> {

    /**
     * 查询APP/小程序用户
     *
     * @param page
     * @param criteria
     * @return
     */
    Page<APPUser> queryAPPUser(Page<APPUser> page, @Param("criteria") UserQueryCriteria criteria);


    /**
     * 根据条件查询一个用户
     *
     * @param appUserQuery
     * @return
     */
    APPUser selectByQueryOne(@Param("appUserQuery") APPUserQuery appUserQuery);

    AppRoleDto selectRoleByUserLevel(Byte userLevel);

    APPUser findByUsername(@Param("username") String username);

    void setUsername(String phoneNumber);



    APPUser appFindByUsername(@Param("username") String username);

    @Select("select * from app_user where username=#{username}")
    APPUserQuery getByUsername(@Param("username") String username);

    @Select("select * from user where username=#{username} and password=#{password}")
    User getByUsernameAndPassword(@Param("username") String username, @Param("password") String password);

}
