/*
 *  Copyright 2019-2025 Zheng Jie
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.fuyuanshen.modules.system.service.impl.app;

import cn.hutool.core.util.RandomUtil;
import cn.hutool.crypto.digest.MD5;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fuyuanshen.exception.BadRequestException;
import com.fuyuanshen.modules.system.domain.Role;
import com.fuyuanshen.modules.system.domain.app.APPUser;
import com.fuyuanshen.modules.system.domain.dto.UserQueryCriteria;
import com.fuyuanshen.modules.system.domain.dto.app.APPForgotPasswordDTO;
import com.fuyuanshen.modules.system.domain.dto.app.APPUserDTO;
import com.fuyuanshen.modules.system.mapper.app.APPUserMapper;
import com.fuyuanshen.modules.system.service.app.APPUserService;
import com.fuyuanshen.modules.utils.ResponseVO;
import com.fuyuanshen.utils.*;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.Set;

import static com.fuyuanshen.constants.RedisConstants.APP_SMS_TOKEN;

/**
 * @author Zheng Jie
 * @date 2018-11-23
 */
@Service
@RequiredArgsConstructor
public class APPUserServiceImpl extends ServiceImpl<APPUserMapper, APPUser> implements APPUserService {

    private final APPUserMapper appUserMapper;

    private final PasswordEncoder passwordEncoder;

    @Autowired
    private final RedisUtils redisUtils;


    /**
     * 查询APP/小程序用户
     *
     * @param criteria
     * @param page
     * @return
     */
    @Override
    public PageResult<APPUser> queryAPPUser(UserQueryCriteria criteria, Page<APPUser> page) {
        Page<APPUser> appUserPage = appUserMapper.queryAPPUser(page, criteria);
        PageResult<APPUser> pageResult = new PageResult<>();
        pageResult.setContent(appUserPage.getRecords());
        pageResult.setTotalElements(appUserPage.getTotal());
        return pageResult ;
    }

    @Override
    public APPUser getLoginData(String userName) {
        return appUserMapper.appFindByUsername(userName);
    }

    @Override
    public ResponseVO<Object> addUser(APPUserDTO user) {

        String username = user.getPhoneNumber();
        if (appUserMapper.getByUsername(username) != null) {
            throw new BadRequestException("该手机号已被注册");
        }
        APPUser appUser = new APPUser();
        appUser.setUsername(user.getPhoneNumber());

        appUser.setPassword(user.getPassword());
        appUser.setNickName(user.getPhoneNumber());
        appUser.setUserLevel((byte) 1);
        appUser.setPhone(Long.valueOf(user.getPhoneNumber()));
        appUser.setAdmin((byte) 1);
        appUser.setEnabled(true);
        appUser.setUserType(0);
        System.out.println("--------------------"+appUser);


        appUserMapper.insert(appUser);
        return ResponseVO.success("注册成功");

    }

    @Override
    public Integer selectRoleByUserLevel(Set<Role> roles) {
        return 0;
    }

    @Override
    public void forgotPassword(APPForgotPasswordDTO appForgotPasswordDTO) {
        String phoneNumber = appForgotPasswordDTO.getPhoneNumber();
        APPUser appUser = appUserMapper.appFindByUsername(phoneNumber);
        if (appUser == null) {
            throw new BadRequestException("手机号不存在");
        }
        Object verificationCode = redisUtils.get(APP_SMS_TOKEN + phoneNumber);
        if (verificationCode == null) {
            throw new BadRequestException("验证码已过期");
        }
        if(!appForgotPasswordDTO.getVerificationCode().equals(verificationCode.toString())){
            throw new BadRequestException("验证码错误");
        }
        appUser.setPassword(appForgotPasswordDTO.getPassword());
        appUserMapper.updateById(appUser);
    }

    @Override
    public void sendSms(String phoneNumber) {
        if (appUserMapper.appFindByUsername(phoneNumber) == null) {
            throw new BadRequestException("手机号不存在");
        }
        // todo 发送验证码

        redisUtils.set(APP_SMS_TOKEN + phoneNumber, RandomUtil.randomNumbers(4), 5 * 60);

    }

}
